@@ -8,6 +8,8 @@ export class Trimmer extends Component {
     source: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
     width: PropTypes.number,
     height: PropTypes.number,
+    showTrackerHandle: PropTypes.bool,
+    trackerHandleColor: PropTypes.string,
     themeColor: PropTypes.string,
     onChange: PropTypes.func,
     onTrackerMove: PropTypes.func,
@@ -21,7 +23,9 @@ export class Trimmer extends Component {
 
   static defaultProps = {
     themeColor: 'gray',
-    trackerColor: 'black'
+    trackerColor: 'black',
+    trackerHandleColor: 'gray',
+    showTrackerHandle: false
   };
 
   constructor(...args) {
@@ -58,6 +62,8 @@ export class Trimmer extends Component {
       trackerColor,
       thumbWidth,
       borderWidth,
+      showTrackerHandle,
+      trackerHandleColor
     } = this.props;
     const actualSource = getActualSource(source);
     return (
@@ -68,6 +74,8 @@ export class Trimmer extends Component {
         currentTime={currentTime}
         themeColor={processColor(themeColor).toString()}
         trackerColor={processColor(trackerColor).toString()}
+        showTrackerHandle={showTrackerHandle}
+        trackerHandleColor={processColor(trackerHandleColor).toString()}
         onTrackerMove={this._handleTrackerMove}
         pointerEvents={'box-none'}
         onChange={this._onChange}
